qpsphere
========

|PyPI Version| |Tests Status| |Coverage Status| |Docs Status|


**qpsphere** is a Python3 library for analyzing spherical objects in quantitative phase imaging.


Documentation
-------------

The documentation, including the reference and examples, is available on `readthedocs.io <https://qpsphere.readthedocs.io/en/stable/>`__.


Installation
------------

::

    pip install qpsphere


Testing
-------

::

    pip install -e .
    python setup.py test
    

.. |PyPI Version| image:: http://img.shields.io/pypi/v/qpsphere.svg
   :target: https://pypi.python.org/pypi/qpsphere
.. |Tests Status| image:: http://img.shields.io/travis/RI-imaging/qpsphere.svg?label=tests
   :target: https://travis-ci.org/RI-imaging/qpsphere
.. |Coverage Status| image:: https://img.shields.io/codecov/c/github/RI-imaging/qpsphere/master.svg
   :target: https://codecov.io/gh/RI-imaging/qpsphere
.. |Docs Status| image:: https://readthedocs.org/projects/qpsphere/badge/?version=latest
   :target: https://readthedocs.org/projects/qpsphere/builds/

